#
# spec file for package gutenprint
#
# Copyright (c) 2018 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gutenprint
Url:            http://gutenprint.sourceforge.net
Version:        5.2.14
Release:        150000.3.2.2
%define tarball_version %{version}
#define tarball_version 5.2.14-pre2
%define gutenprintmajor 5.2
BuildRequires:  cairo-devel
# SLE10 and SLE11 and SLE12 need special BuildRequires.
# For suse_version values see https://en.opensuse.org/openSUSE:Build_Service_cross_distribution_howto
%if 0%{?suse_version} != 1010 && 0%{?suse_version} != 1110 && 0%{?suse_version} != 1315
# Anything what is not SLE10 or SLE11 or SLE12 (i.e. all openSUSE versions) have "normal" BuildRequires.
BuildRequires:  cups-ddk
BuildRequires:  cups-devel
%endif
%if 0%{?suse_version} == 1110 || 0%{?suse_version} == 1010
# On SLE11 and SLE10 there is the separated package cupsddk.
BuildRequires:  cups-devel
BuildRequires:  cupsddk
%endif
%if 0%{?suse_version} == 1315
# For SLE12 by default CUPS 1.7.5 is provided and alternatively CUPS 1.5.4 is provided in the "legacy" module.
# For SLE12 build it with traditional CUPS 1.5.4 to ensure it works on SLE12 both with CUPS 1.7.5 and CUPS 1.5.4.
# Only in the Printing project for SLE12 use cups154-ddk (a sub package of the cups154-SLE12 source package):
BuildRequires:  cups154-ddk
BuildRequires:  cups154-devel
%endif
BuildRequires:  gimp-devel
BuildRequires:  glib2-devel
BuildRequires:  gtk2-devel
BuildRequires:  libpng-devel
BuildRequires:  libtiff-devel
%if 0%{?suse_version} >= 1140
# The CUPS dyesub USB backend requires libusb-1.0 which is available since openSUSE 11.4.
# When libusb-1.0 is not available, the configure magic does not build the CUPS dyesub USB backend.
BuildRequires:  libusb-1_0-devel
%endif
BuildRequires:  pango-devel
%if 0%{?suse_version} != 1010
# On SLE10 there is no python-cups. Simply omit it because that BuildRequires is only there to
# add python-cups BuildRequires to have postscriptdriver() Provides for the drivers in gutenprint.
BuildRequires:  python-cups
%endif
Summary:        Printer drivers for CUPS from the Gutenprint project
License:        GPL-2.0+
Group:          Hardware/Printing
# The "rastertogutenprint" filter requires CUPS and the "cups" output device in Ghostscript:
%if 0%{?suse_version} == 1010
# For SLE10 it must be built with --disable-escputil because in SLE10 escputil is provided by ghostscript-library
%define enable_or_disable_escputil disable-escputil
# For SLE10 it must be built with --disable-cups-1_2-enhancements because SLE10 has CUPS 1.1
%define enable_or_disable_cups_1_2_enhancements disable-cups-1_2-enhancements
Requires:       cups
%else
%define enable_or_disable_escputil enable-escputil
%define enable_or_disable_cups_1_2_enhancements enable-cups-1_2-enhancements
Requires:       cups >= 1.2.2
%endif
%if 0%{?suse_version} == 1110 || 0%{?suse_version} == 1010
# For SLE11 and SLE10 it must be built --without-gimp2 because since Gutenprint 5.2.13
# the gimp_pixels_to_units function is called in in src/gimp2/print.c and according to
# https://developer.gimp.org/api/2.0/libgimpbase/libgimpbase-gimpunit.html
# the gimp_pixels_to_units function is available since GIMP 2.8
# but SLE11 provides GIMP 2.6.2 and SLE10 provides GIMP 2.2.10:
%define with_or_without_gimp2 without-gimp2
# Let the main package confict with an installed gutenprint-gimpplugin <= 5.2.12
# which intentionally should break an automated RPM package version upgrade
# to make the user aware that by installing Gutenprint 5.2.13
# there will be no longer a gutenprint-gimpplugin:
Conflicts:      gutenprint-gimpplugin < 5.2.13
%else
%define with_or_without_gimp2 with-gimp2
%endif
# Up to openSUSE 12.1 the package cups has "Requires: ghostscript_any" so that the above
# "Requires: cups" is sufficient to also get the "cups" output device in Ghostscript.
# Since openSUSE 12.2 the package cups has only "Recommends: ghostscript" to avoid
# an implicit build dependency cycle between the main-packages cups and ghostscript.
# Therefore after openSUSE 12.1 gutenprint needs an explicit "Requires: ghostscript"
# to ensure that the "cups" output device in Ghostscript is available:
%if 0%{?suse_version} > 1210
Requires:       ghostscript
%endif
# Install into this non-root directory (required when it is built as non-root user):
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# URL for Source0 automated download:
# https://sourceforge.net/projects/gimp-print/files/gutenprint-5.2/5.2.14/gutenprint-5.2.14.tar.bz2/download
# How to get Source0 directly:
# wget --no-check-certificate -O gutenprint-5.2.14.tar.bz2 https://sourceforge.net/projects/gimp-print/files/gutenprint-5.2/5.2.14/gutenprint-5.2.14.tar.bz2
Source0:        http://downloads.sourceforge.net/gimp-print/%{name}-%{version}.tar.bz2
# How to get Source0 directly:
# wget --no-check-certificate -O gutenprint-5.2.14-pre2.tar.bz2 https://downloads.sourceforge.net/project/gimp-print/gutenprint-5.2/5.2.14-pre1/gutenprint-5.2.14-pre2.tar.bz2
#Source0:        gutenprint-5.2.14-pre2.tar.bz2
# Patch0...Patch9 is for patches from upstream:
# Patch10...Patch99 is for openSUSE patches which which are intended for upstream:

%description
The Gutenprint (formerly Gimp-Print) printer drivers for CUPS.
See the user's manual at /usr/share/gutenprint/doc/gutenprint-users-manual.pdf

%package devel
Summary:        Development environment for Gutenprint
Group:          Development/Libraries/C and C++
Requires:       cups >= 1.2.2
Requires:       ghostscript-library >= 7.05
Requires:       glibc-devel
Requires:       gtk2-devel
Requires:       gutenprint = %{version}

%description devel
The development environment for the Gutenprint printer drivers.
See the developers guide to Gutenprint at /usr/share/gutenprint/doc/gutenprint.pdf

%if 0%{?suse_version} > 1110
# For SLE11 and SLE10 it is built --without-gimp2 (see above):
%package gimpplugin
Summary:        Alternative GIMP print plug-in from the Gutenprint project
Group:          Hardware/Printing

%description -n gutenprint-gimpplugin
The enhanced Gutenprint GIMP print plug-in offers an alternative
with additional capabilities to the plugin supplied with GIMP.
See the user's manual at /usr/share/gutenprint/doc/gutenprint-users-manual.pdf
%endif

%prep
# Be quiet when unpacking:
%setup -q -n gutenprint-%{tarball_version}

%build
#autoreconf -fvi
# No need to set our preferred architecture-specific flags for the compiler and linker
# via something like export CFLAGS="$RPM_OPT_FLAGS" and export CXXFLAGS="$RPM_OPT_FLAGS"
# because the RPM macro configure does that:
%configure \
           --disable-static \
           --disable-silent-rules \
           --enable-test \
           --enable-cups-ppds \
           --enable-simplified-cups-ppds \
           --disable-translated-cups-ppds \
           --enable-libgutenprintui2 \
           --%{enable_or_disable_escputil} \
           --%{enable_or_disable_cups_1_2_enhancements} \
           --%{with_or_without_gimp2}
make %{?_smp_mflags}
# Do not run "make check" here because it fails.
# But "make DESTDIR=$RPM_BUILD_ROOT installcheck" works (see below).

%install
# Create required directories first:
install -d -m755 $RPM_BUILD_ROOT/bin
install -d -m755 $RPM_BUILD_ROOT/usr/share/cups/model
install -d -m755 $RPM_BUILD_ROOT/usr/lib/cups/filter
install -d -m755 $RPM_BUILD_ROOT/%{_libdir}/gutenprint/%{gutenprintmajor}
# Install Gutenprint:
make DESTDIR=$RPM_BUILD_ROOT install
# Run self-tests using the binaries in their installed location:
make DESTDIR=$RPM_BUILD_ROOT installcheck
# Remove libtool archives
rm -rf %{buildroot}%{_libdir}/*.la
# Work with upstream compliant CUPS 1.4 on all platforms
# which means to have a fixed "/usr/lib/cups/" directory
# on all platforms (see Novell/Suse Bugzilla bnc#575544).
# Do not do this for SLE11 and SLE10 where still /usr/lib64/cups/ is used on x86_64:
%if 0%{?suse_version} > 1110
for D in lib32 lib64
do for F in commandtocanon commandtoepson rastertogutenprint.%{gutenprintmajor}
   do if test -e $RPM_BUILD_ROOT/usr/$D/cups/filter/$F
      then mv -f $RPM_BUILD_ROOT/usr/$D/cups/filter/$F $RPM_BUILD_ROOT/usr/lib/cups/filter/$F
      fi
   done
   F="gutenprint.%{gutenprintmajor}"
   if test -e $RPM_BUILD_ROOT/usr/$D/cups/driver/$F
   then mv -f $RPM_BUILD_ROOT/usr/$D/cups/driver/$F $RPM_BUILD_ROOT/usr/lib/cups/driver/$F
   fi
done
%endif
%if 0%{?suse_version} != 1010
# Skip that on SLE10 because there is no .../cups/driver/ directory.
# Disable the run-time PPD generator /usr/lib/cups/driver/gutenprint.5.2
# so that it is not executed by the cups-driverd (e.g. in response to a "lpinfo -m" request)
# to avoid duplicated PPDs because we create the PPDs during compile-time (via --enable-cups-ppds)
# and provide ready-made PPDs in /usr/share/cups/model/gutenprint/... in the RPM package
# see "Regarding CUPS PPD files" at https://bugzilla.novell.com/show_bug.cgi?id=514994#c9
%if 0%{?suse_version} == 1110
# On SLE11 there is still /usr/lib64/cups/ used on x86_64.
chmod a-x $RPM_BUILD_ROOT%_libdir/cups/driver/gutenprint.%{gutenprintmajor}
%else
chmod a-x $RPM_BUILD_ROOT/usr/lib/cups/driver/gutenprint.%{gutenprintmajor}
%endif
%endif
# Move the special testpattern generator away from the usual bin directory:
mv $RPM_BUILD_ROOT/%{_bindir}/testpattern $RPM_BUILD_ROOT/%{_libdir}/gutenprint/%{gutenprintmajor}
# Remove dispensable .po files (only the .mo files are needed on the end-users's system):
rm $RPM_BUILD_ROOT/usr/share/locale/*/gutenprint_*.po
%find_lang gutenprint

%post
/sbin/ldconfig
# update quietly Gutenprint PPD files in /etc/cups/ppd/ if such PPD files exist
# using the new PPD files under /usr/share/cups/model/gutenprint/ as templates
# see https://bugzilla.novell.com/show_bug.cgi?id=637455
/usr/sbin/cups-genppdupdate -q || /bin/true
# exit successfully in any case:
exit 0

%postun
/sbin/ldconfig
# exit successfully in any case:
exit 0

%files -f gutenprint.lang
%defattr(-,root,root)
%config /etc/cups/command.types
%{_bindir}/cups-calibrate
%if 0%{?suse_version} != 1010
# In SLE10 escputil is provided by ghostscript-library
%{_bindir}/escputil
%endif
%{_sbindir}/cups-genppd*
%dir %{_libdir}/gutenprint
%dir %{_libdir}/gutenprint/%{gutenprintmajor}
%{_libdir}/gutenprint/%{gutenprintmajor}/*
%{_libdir}/libgutenprint*.so?*
%dir /usr/share/cups
/usr/share/cups/calibrate.ppm
%dir /usr/share/cups/model
%dir /usr/share/cups/model/gutenprint
%dir /usr/share/cups/model/gutenprint/%{gutenprintmajor}
%dir /usr/share/cups/model/gutenprint/%{gutenprintmajor}/C
/usr/share/cups/model/gutenprint/%{gutenprintmajor}/C/*
%if 0%{?suse_version} == 1110 || 0%{?suse_version} == 1010
# On SLE11 and SLE10 there is still /usr/lib64/cups/ used on x86_64.
%if 0%{?suse_version} != 1010
# On SLE10 there is no .../cups/driver/ directory
%dir %_libdir/cups/driver
%_libdir/cups/driver/gutenprint.%{gutenprintmajor}
%endif
%_libdir/cups/filter/commandtocanon
%_libdir/cups/filter/commandtoepson
%_libdir/cups/filter/rastertogutenprint.%{gutenprintmajor}
%else
%dir /usr/lib/cups/driver
/usr/lib/cups/driver/gutenprint.%{gutenprintmajor}
/usr/lib/cups/filter/commandtocanon
/usr/lib/cups/filter/commandtoepson
/usr/lib/cups/filter/rastertogutenprint.%{gutenprintmajor}
%endif
%if 0%{?suse_version} >= 1140
/usr/lib/cups/backend/gutenprint52+usb
%dir /usr/share/cups/usb
/usr/share/cups/usb/net.sf.gimp-print.usb-quirks
%endif
%dir /usr/share/gutenprint
%dir /usr/share/gutenprint/%{gutenprintmajor}
/usr/share/gutenprint/%{gutenprintmajor}/*
%dir /usr/share/gutenprint/samples/
/usr/share/gutenprint/samples/*
%dir /usr/share/gutenprint/doc
%doc /usr/share/gutenprint/doc/*
%doc /usr/share/man/man?/*.gz

%files devel
%defattr(-,root,root)
%dir /usr/include/gutenprint
/usr/include/gutenprint/*
%dir /usr/include/gutenprintui2
/usr/include/gutenprintui2/*
%{_libdir}/pkgconfig/gutenprint*
%{_libdir}/libgutenprint*.so

%if 0%{?suse_version} > 1110
# For SLE11 and SLE10 it is built --without-gimp2 (see above):
%files gimpplugin
%defattr(-,root,root)
%dir %{_libdir}/gimp
%dir %{_libdir}/gimp/2.0
%dir %{_libdir}/gimp/2.0/plug-ins
%{_libdir}/gimp/2.0/plug-ins/*
%endif

%changelog
* Mon Apr 23 2018 jsmeix@suse.de
- Version upgrade to 5.2.14:
  Additional changes in this release (compared to 5.2.13pre14.2):
  * Color quality of the PCL 5c driver is significantly improved.
  For details see the NEWS file.
* Thu Jan  4 2018 jsmeix@suse.de
- Version upgrade to 5.2.13pre14.2 which is the
  second pre-release of Gutenprint 5.2.14.
  Major changes in this release (compared to 5.2.13):
  * The PCL driver now supports color laser printers
    that use PCL 5c natively (as opposed to emulation).
    The support is considered to be preliminary at this time.
    Tons of PCL printers have been added with color support.
    Please report success or failure with PCL color laser printers
    using the Generic PCL Color drivers.
    Based on feedback from this pre-release, some or all of these
    printers may be removed from the list prior to 5.2.14 release.
  * Support for the Brother HL-2030 and HL-2035 has been removed
    because these printers do not support standard PCL.
  * A crash that affected certain dyesub printers when used with
    simplified PPD files has been fixed.
  * Enhanced support for some dye-sublimation printers.
  For details see the NEWS file.
* Thu Aug 31 2017 jsmeix@suse.de
- Version upgrade to 5.2.13:
  Major changes in this release (compared to 5.2.12):
  * Correct mis-defined paper type that collided with standard
    A4 paper. This resulted in some Canon and PCL printers
    mishandling A4 paper.
  * Code optimizations in the dye-sublimation driver, resulting
    in a significant (2x-2.7x) boost in performance.
  * The Canon driver has improved printer firmware papersize
    detection when using automatic paper source (Autofeed).
  * Added support for two Epson inkjet printers.
  * Added experimental support for many Canon printers.
  * Removed support for iP100 (unsupported).
  * Added the Datamax-O'Neil H class series of printers.
  For details see the NEWS file.
- For SLE11 and SLE10 it must be built --without-gimp2
  because since Gutenprint 5.2.13 the gimp_pixels_to_units function
  is called in in src/gimp2/print.c and according to
  https://developer.gimp.org/api/2.0/libgimpbase/libgimpbase-gimpunit.html
  the gimp_pixels_to_units function is available since GIMP 2.8
  but SLE11 provides GIMP 2.6.2 and SLE10 provides GIMP 2.2.10.
  Accordingly the main package conficts with an installed
  gutenprint-gimpplugin <= 5.2.12 which intentionally should
  break an automated RPM package version upgrade
  to make the user aware that by installing Gutenprint 5.2.13
  there is no longer a gutenprint-gimpplugin for SLE11 or SLE10.
* Wed Aug  2 2017 tchvatal@suse.com
- Drop default configure options that do not need to be overriden
- Drop again static libraries that are forbidden by default
- Switch check to proper check phase to allow --no-check override
- Pass disable-silent-rules to see all the compile options for
  brp parsers
- Switch to full URL for sources to have autodownload/tarball
  verification working
- Make sure the tests are forced on during configure phase
- Drop initial rm in install phase as we by default have empty dir
  courtesy of OBS
- Remove libtool archives as they are not supposed to be shipped
  on today packages
* Tue Mar 14 2017 jsmeix@suse.de
- Have libgutenprint.a and libgutenprintui2.a
  in the gutenprint-devel sub-packege.
* Wed Feb  8 2017 jsmeix@suse.de
- Version upgrade to 5.2.12:
  For major changes in this release (compared to 5.2.11)
  see the next entry dated "Tue Sep 20 15:09:34 CEST 2016".
  For details see the NEWS file.
* Tue Sep 20 2016 jsmeix@suse.de
- Version upgrade to 5.2.11pre12.2 which is the
  second pre-release of Gutenprint 5.2.12.
  Major changes in this release (compared to 5.2.11):
  * The Ghostscript IJS driver and Foomatic data generator
    have been removed.  CUPS is ubiquitous on Linux/UNIX systems,
    and the Ghostscript IJS driver and Foomatic data are
    not needed with CUPS.
  * Added support for some dye sublimation printers.
  * Improved support (and bugfixes) for several dye sublimation
    printers.
  * Backend now reports media status via standard CUPS marker
    attributes some particular dye sublimation printers.
  * Added support for some Epson inkjet printers.
  * Added support for most Datamax-O'Neil DPL printers.
  For details see the NEWS file.
* Wed Feb  3 2016 jsmeix@suse.de
- Version upgrade to 5.2.11:
  * Added and enhanced support (and bugfixes) for many
    dye sublimation printers.
    Some dye sublimation printer models utilize a print engine
    that requires the host system to process the print data using
    unknown algorithms. Until these algorithms can be determined
    and re-implemented, these models are unsuitable for general
    use due to very poor output quality.
  * Added support for some Datamax-O'Neil PCL printers.
  * Added support for some Epson inkjet printers.
  * Added support for many Canon inkjet printers
    (mostly for PIXMA, PIXUS and MAXIFY models)
    and bugfixes (mainly for several BJC models).
    For most Canon inkjet printers the current
    support status is still EXPERIMENTAL, see
    http://gimp-print.sourceforge.net/p_Supported_Printers.php
  For details see the NEWS file.
* Wed Oct  7 2015 jsmeix@suse.de
- Version upgrade to 5.2.10pre11.2 which is the
  second pre-release of Gutenprint 5.2.11.
  Major changes in this release (compared to 5.2.10pre11.1):
  * Support for a few additional Epson inkjet printers.
  For details see the NEWS file.
- define_GNU_SOURCE_makes_isblank_known.patch is obsolete
  because it is fixed in the sources.
* Thu Jul 16 2015 jsmeix@suse.de
- Make it build again for SLE10 (cf. "SLE10" spec file comments).
- define_GNU_SOURCE_makes_isblank_known.patch adds
  "#define _GNU_SOURCE" in escputil/d4lib.c because isblank()
  needs _XOPEN_SOURCE >= 600 (see "man 3 isblank"
  and "man 7 feature_test_macros") otherwise compile fails
  with "error: implicit declaration of function 'isblank'".
* Mon Jun 29 2015 jsmeix@suse.de
- Version upgrade to 5.2.10pre11.1 which is the
  first pre-release of Gutenprint 5.2.11.
  Major changes in this release:
  * Initial support for Datamax-O'Neil label printers:
    the Performance series and the Workstation printer.
  * Support for additional dye sublimation printers,
    and improvements, bug fixes for others.
  * Support for additional Canon inkjet printers,
    and bug fixes for others.
  For details see the NEWS file.
* Wed Mar 18 2015 jsmeix@suse.de
- Make it build for SLE12 with traditional CUPS 1.5.4 to ensure
  it works on SLE12 both with CUPS 1.7.5 and CUPS 1.5.4 because
  for SLE12 by default CUPS 1.7.5 is provided and alternatively
  CUPS 1.5.4 is provided in the "legacy" module, cf.
  https://www.suse.com/releasenotes/x86_64/SUSE-SLES/12/
* Tue Mar 17 2015 jsmeix@suse.de
- To make it build on SLE11 it BuildRequires cupsddk because
  on SLE11 with its CUPS 1.3.9 there is the separated package
  cupsddk (otherwise it is cups-ddk a sub-package of cups).
* Mon Jun  2 2014 jsmeix@suse.de
- Version upgrade to 5.2.10:
  * Added a unified CUPS backend 'gutenprint52+usb' that requires
    libusb 1.0 (or newer) to support selected dye sublimation
    printers. Support for all Canon SELPHY CP- and ES- printers
    has been improved considerably through that CUPS backend.
  * Added duplex support for the EPSON WorkForce 630, 635,
    and 645, and NX635.
  * Many new printers supported in this release.
  * Very many new printers supported experimentally.
  For details see the NEWS file.
- For openSUSE 11.4 or newer BuildRequires libusb-1_0-devel
  to build the 'gutenprint52+usb' backend. When libusb-1.0 is
  not installed, the configure magic does not build that backend.
  The installed /usr/share/cups/usb/net.sf.gimp-print.usb-quirks
  needs a current CUPS version (that supports usb quirks).
  Older CUPS versions would ignore gutenprint's usb quirks
  which means that the generic CUPS backend 'usb' reports
  in particular the dye sublimation printers that do not work
  with it but require the special 'gutenprint52+usb' backend.
* Wed Jan 23 2013 jsmeix@suse.de
- Do no longer send SIGHUP to cupsd in RPM post install script
  (which would let the cupsd recognize new and updated PPD files
  see the entry dated "Fri Sep 24 10:45:28 CEST 2010" below)
  because SIGHUP to cupsd makes active print jobs fail
  (see bnc#637455 starting at comment#3).
- Added explicit "Requires: ghostscript" if suse_version > 1210
  because since openSUSE 12.2 cups only "Recommends: ghostscript"
  (to avoid a build dependency cycle) so that gutenprint needs
  an explicit "Requires: ghostscript" for the "cups" device in
  Ghostscript that is required by "rastertogutenprint" (compare
  the entry dated "Thu Apr 28 17:20:03 CEST 2011" below).
* Wed Sep 26 2012 mmeister@suse.com
- Version upgrade to 5.2.9:
  Revert an inappropriate change to the internal library version
  number that was introduced in the 5.2.8 release.
- Version upgrade to 5.2.8:
  The Canon driver has been significantly overhauled. Its output
  and functionality may be significantly different from previous
  releases. Further work in future releases is expected.
  Several Canon PIXMA and SELPHY printers were removed, as they
  are not supported.
  Several Canon printers do not offer a grayscale printing mode.
  CD printing support for some Canon PIXMA printers was added.
  Added borderless functionality to most Canon printers
  (except S series and BJC series).
  Many new Canon printers are now EXPERIMENTAL supported.
  A few new Epson printers are now supported.
  For details see the NEWS file.
- escputil-send_nulls-void.patch is obsolete because its fixed
  in the sources.
- compile-fix.patch is obsolete because its fixed in the sources.
* Thu Oct 13 2011 aj@suse.de
- compile-fix.patch adds missing includes.
* Fri May 27 2011 vuntz@opensuse.org
- Add python-cups BuildRequires to have postscriptdriver() Provides
  for the drivers in gutenprint.
* Tue May 17 2011 jsmeix@suse.de
- Upgraded to version 5.2.7:
  This release features support for many additional Canon inkjets,
  some Epson inkjets, and some dye sublimation printers,
  greatly upgraded support for many Epson Stylus Pro printers,
  and numerous bug fixes.
  For details see the NEWS file.
- escputil-send_nulls-void.patch makes send_nulls a void function
  because nowhere is a return value of send_nulls used
  to fix a "no-return-in-nonvoid-function escputil.c:683" error.
* Thu Apr 28 2011 jsmeix@suse.de
- Removed the needless RPM requirement for pstoraster.
- Removed the duplicate RPM requirement for ghostscript-library
  because there is a RPM requirement for cups
  and cups requires ghostscript.
* Wed Dec 29 2010 jsmeix@suse.de
- Added missing directories for /usr/lib/gimp/2.0/plug-ins/*
  to the "gimpplugin" files section in the RPM spec file.
- Marked /usr/share/gutenprint/doc/* as "doc" in the RPM
  spec file (see Novell/openSUSE Bugzilla bnc#661350).
* Fri Sep 24 2010 jsmeix@suse.de
- Removed gutenprint-5.2.6-make_A4_DefaultPageSize.patch
  because it is useless because the DefaultPageSize in the PPD
  templates in /usr/share/cups/model/ does not matter because
  the cupsd sets the DefaultPageSize for PPDs in /etc/cups/ppd/
  by default according to the locale that the cupsd runs in or
  according to a DefaultPaperSize entry in /etc/cups/cupsd.conf.
- Run cups-genppdupdate in the RPM post install script to update
  Gutenprint PPD files in /etc/cups/ppd/ if such PPDs exist
  (see Novell/openSUSE Bugzilla bnc#637455).
* Thu Sep  2 2010 jsmeix@suse.de
- Disable the PPD generator /usr/lib/cups/driver/gutenprint.5.2
  to avoid duplicated PPDs because we provide ready-made PPDs
  in /usr/share/cups/model/gutenprint/... in the RPM package
  (see Novell/openSUSE Bugzilla bnc#514994 comment#9
  the section "Regarding CUPS PPD files").
* Wed Sep  1 2010 jsmeix@suse.de
- gutenprint-5.2.6-make_A4_DefaultPageSize.patch
  moves the paper definition for "A4" to the top of the list
  to make A4 the DefaultPageSize in the Gutenprint PPDs.
- Upgraded to version 5.2.6:
  This release offers additional support for Epson Stylus Pro
  printers, along with some changes for other Epson printers
  and support for additional Canon inkjets and PCL laser
  printers over 5.2.5. For details see the NEWS file.
- Upgraded to version 5.2.5:
  This release offers several fixes, new features, and support
  for new printers over 5.2.4. For details see the NEWS file.
* Fri Aug 13 2010 jsmeix@suse.de
- Split gutenprint from the cups-drivers package to have it as a
  stand-alone package (see Novell/openSUSE Bugzilla bnc#514994).
  The IJS driver /usr/bin/ijsgutenprint is no longer provided
  because it is not recommend if CUPS is used. Only the native
  CUPS driver is provided as recommend, see the README file.
